@@ -41,7 +41,7 @@ void DecompressChannel(const uint32_t* input,
                      const ptrdiff_t volume_size[3],
                      const ptrdiff_t block_size[3],
                      const ptrdiff_t strides[4],
-                     std::vector<Label>* output,
+                     Label* output,
                      const ptrdiff_t channel);
 
 // Encodes multiple channels.
@@ -66,7 +66,7 @@ void DecompressChannels(const uint32_t* input,
                       const ptrdiff_t volume_size[4],
                       const ptrdiff_t block_size[3],
                       const ptrdiff_t strides[4],
-                      std::vector<Label>* output);
+                      Label* output);
 
 }  // namespace compress_segmentation
 
